@@ -1,4 +1,5 @@
 import os
+import re
 from importlib import reload
 from os import getcwd
 from typing import Callable, Union
@@ -92,6 +93,33 @@ def check_plot(file_name: str, plot_function: Callable, set_size_w_h: Union[tupl
     assert os.path.isfile(file_name)
 
 
+def clean_formatted_dataframe(rendered):
+    """`This dataframe changes the random code generated when saving formatted dataframes
+    (i.e df.style.render()). This is necessary because it each time unit tests are ran, the html changes,
+    and it is difficult to know if the change/diff occurred because of the random code, or because something
+    actually changed.
+
+    For example, it changes the `1ef9B` in
+
+    ```
+    '<style type="text/css">\n#T_1ef9B_row0_col0, #T_1ef9B_row0_col1, ...
+    ```
+
+    to `99999`:
+
+    ```
+    '<style type="text/css">\n#T_99999_row0_col0, #T_99999_row0_col1, ...
+    ```
+    `"""
+    temp = rendered.replace('\n', '')
+    if temp.startswith('<style type="text/css"></style>'):
+        code = re.sub('_">  <.*', '_', temp).replace('<style type="text/css"></style><table id="T', '')
+    else:
+        code = re.sub('_row.*', '_', temp).replace('<style type="text/css">#T', '')
+
+    return rendered.replace(code, '_99999_')
+
+
 def get_data_credit() -> pd.DataFrame:
     # https://www.openml.org/d/31
     # save locally in case dataset changes or is removed
@@ -127,6 +155,9 @@ def get_data_housing() -> pd.DataFrame:
 def helper_test_dataframe(file_name, dataframe):
     if os.path.isfile(file_name):
         os.remove(file_name)
+
+    pd.set_option('display.max_rows', None)
+
     with redirect_stdout_to_file(file_name):
         print_dataframe(dataframe)
     assert os.path.isfile(file_name)
